gui = {
  title = "Warehouse deliveries",
  description = "Report the number of monorail cars required to fill the adjacent warehouse to a network",
  fields = {
    network = {
      title = "Network",
      type = "string",
      options = {
        lan = "LAN",
        wifi = "Wifi",
      },
      description = "The target network to receive signals",
      default = "lan",
      order = "a",
    },
    item = {
      title = "Item",
      type = "item",
      description = "Item to monitor",
      default = "",
      order = "b",
    },
    signal = {
      title = "Signal",
      type = "string",
      description = "Signal to send",
      default = "cars",
      order = "c",
    },
    heartbeat = {
      title = "Send Heartbeat",
      type = "boolean",
      description = "Send a 'heartbeat' signal to let others know we are alive",
      default = true,
      order = "d",
    },
    log = {
      title = "Log Activity",
      type = "boolean",
      description = "Periodically log activity to console",
      default = true,
      order = "e",
    },
  },
}

function main()
  local warehouse = api.adjacent_warehouse()

  -- check we have something to monitor
  if warehouse == 0 then
    print("no adjacent warehouse detected; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  local fields = api.gui_fields()

  if not api.is_item(fields.item) then
    print("no item set; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  if #fields.signal == 0 then
    print("no signal set; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  api.color(api.colors.ok)

  local logging = fields.log and api.every(1)
  local send = fields.network == "lan" and api.lan_send or api.wifi_send

  if fields.heartbeat then
    send("heartbeat",1)
  end

  local stacks = api.entity_contents(warehouse)
  local count = stacks[fields.item] or 0
  local cars = math.floor((api.warehouse_capacity(fields.item)-count) / api.monorail_capacity(fields.item))

  send(fields.signal,cars)

  if logging then
    print(fields.signal .. " = " .. cars)
  end
end

