gui = {
  title = "Entity state",
  description = "Report adjacent entity state to a network",
  fields = {
    network = {
      title = "Network",
      type = "string",
      options = {
        lan = "LAN",
        wifi = "Wifi",
      },
      description = "The target network to receive signals",
      default = "lan",
      order = "a",
    },
  },
}

function main()
  local entities = api.entities_adjacent()

  -- check we have something to monitor
  if #entities == 0 then
    print("no adjacent entities detected; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  api.color(api.colors.ok)

  local fields = api.gui_fields()
  local logging = api.every(1)
  local send = fields.network == "lan" and api.lan_send or api.wifi_send

  if logging then
    print("adjacent entities detected: " .. #entities)
  end

  for i,entity in ipairs(entities) do
    local type = api.entity_type(entity)
    local state = api.entity_state(entity)
    local topic = type .. ":" .. state
    if state == "stateless" then continue end
    send(topic,1)
    if logging then
      print(topic,state)
    end
  end
end

