gui = {
  title = "Monorail deliveries",
  description = "Set monorail deliveries from a network",
  fields = {
    network = {
      title = "Network",
      type = "string",
      options = {
        lan = "LAN",
        wifi = "Wifi",
      },
      description = "The source network to receive signals",
      default = "lan",
      order = "a",
    },
    signal = {
      title = "Signal",
      type = "string",
      description = "Name of signal to receive",
      default = "cars",
      order = "b",
    },
    backlog = {
      title = "Backlog",
      type = "integer",
      description = "Extra cars (consider queue length)",
      default = "0",
      order = "c",
    },
    heartbeat = {
      title = "Require Heartbeat",
      type = "boolean",
      description = "Require a 'heartbeat' signal before doing anything",
      default = true,
      order = "d",
    },
    log = {
      title = "Log Activity",
      type = "boolean",
      description = "Periodically log activity to console",
      default = true,
      order = "e",
    },
  }
}

function main()
  local monorail = api.adjacent_monorail()

  -- check we have a monorail to control
  if monorail == 0 then
    print("no adjacent monorail detected; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  local fields = api.gui_fields()

  -- check we have a signal set
  if #fields.signal == 0 then
    api.monorail_cars(monorail,0)
    print("no signal set; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  local logging = fields.log and api.every(1)
  local signals = (fields.network == "lan" and api.lan_signals or api.wifi_signals)()

  -- if heartbeat is required and not present, the network is broken
  if fields.heartbeat and not signals.heartbeat then
    if logging then
      print("no heartbeat; waiting")
    end
    api.monorail_cars(monorail,0)
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  -- check we have a valid signal
  if not signals[fields.signal] then
    print("no signal; waiting")
    api.color(api.colors.warn)
    api.sleep(api.ups())
    return
  end

  api.color(api.colors.ok)

  local cars = signals[fields.signal] + fields.backlog

  -- activity log
  if logging then
    print("max cars = " .. cars)
  end

  if cars ~= api.monorail_cars(monorail) then
    api.monorail_cars(monorail,cars)
    api.color(api.colors.white)
  end
end
